pub struct IndexedCrate {
pub name: String,
pub version: String,
pub root_module_doc: Option<String>,
pub crate_data: Crate,
}Expand description
A single crate that has been indexed via rustdoc JSON.
Fields
name: StringThe crate’s package name (as reported by cargo metadata).
version: StringThe crate’s version string (as reported by cargo metadata).
root_module_doc: Option<String>The crate root’s outer doc comment (//! block), if any. Sourced
from rustdoc_types::Crate::index[root].docs.
crate_data: CrateThe raw parsed rustdoc JSON payload. Retained so the generate and lint stages can walk item / module trees without re-parsing.